/* =======================================================================
 *
 * Parasite animations.
 *
 * =======================================================================
 */

#define FRAME_break01 0
#define FRAME_break02 1
#define FRAME_break03 2
#define FRAME_break04 3
#define FRAME_break05 4
#define FRAME_break06 5
#define FRAME_break07 6
#define FRAME_break08 7
#define FRAME_break09 8
#define FRAME_break10 9
#define FRAME_break11 10
#define FRAME_break12 11
#define FRAME_break13 12
#define FRAME_break14 13
#define FRAME_break15 14
#define FRAME_break16 15
#define FRAME_break17 16
#define FRAME_break18 17
#define FRAME_break19 18
#define FRAME_break20 19
#define FRAME_break21 20
#define FRAME_break22 21
#define FRAME_break23 22
#define FRAME_break24 23
#define FRAME_break25 24
#define FRAME_break26 25
#define FRAME_break27 26
#define FRAME_break28 27
#define FRAME_break29 28
#define FRAME_break30 29
#define FRAME_break31 30
#define FRAME_break32 31
#define FRAME_death101 32
#define FRAME_death102 33
#define FRAME_death103 34
#define FRAME_death104 35
#define FRAME_death105 36
#define FRAME_death106 37
#define FRAME_death107 38
#define FRAME_drain01 39
#define FRAME_drain02 40
#define FRAME_drain03 41
#define FRAME_drain04 42
#define FRAME_drain05 43
#define FRAME_drain06 44
#define FRAME_drain07 45
#define FRAME_drain08 46
#define FRAME_drain09 47
#define FRAME_drain10 48
#define FRAME_drain11 49
#define FRAME_drain12 50
#define FRAME_drain13 51
#define FRAME_drain14 52
#define FRAME_drain15 53
#define FRAME_drain16 54
#define FRAME_drain17 55
#define FRAME_drain18 56
#define FRAME_pain101 57
#define FRAME_pain102 58
#define FRAME_pain103 59
#define FRAME_pain104 60
#define FRAME_pain105 61
#define FRAME_pain106 62
#define FRAME_pain107 63
#define FRAME_pain108 64
#define FRAME_pain109 65
#define FRAME_pain110 66
#define FRAME_pain111 67
#define FRAME_run01 68
#define FRAME_run02 69
#define FRAME_run03 70
#define FRAME_run04 71
#define FRAME_run05 72
#define FRAME_run06 73
#define FRAME_run07 74
#define FRAME_run08 75
#define FRAME_run09 76
#define FRAME_run10 77
#define FRAME_run11 78
#define FRAME_run12 79
#define FRAME_run13 80
#define FRAME_run14 81
#define FRAME_run15 82
#define FRAME_stand01 83
#define FRAME_stand02 84
#define FRAME_stand03 85
#define FRAME_stand04 86
#define FRAME_stand05 87
#define FRAME_stand06 88
#define FRAME_stand07 89
#define FRAME_stand08 90
#define FRAME_stand09 91
#define FRAME_stand10 92
#define FRAME_stand11 93
#define FRAME_stand12 94
#define FRAME_stand13 95
#define FRAME_stand14 96
#define FRAME_stand15 97
#define FRAME_stand16 98
#define FRAME_stand17 99
#define FRAME_stand18 100
#define FRAME_stand19 101
#define FRAME_stand20 102
#define FRAME_stand21 103
#define FRAME_stand22 104
#define FRAME_stand23 105
#define FRAME_stand24 106
#define FRAME_stand25 107
#define FRAME_stand26 108
#define FRAME_stand27 109
#define FRAME_stand28 110
#define FRAME_stand29 111
#define FRAME_stand30 112
#define FRAME_stand31 113
#define FRAME_stand32 114
#define FRAME_stand33 115
#define FRAME_stand34 116
#define FRAME_stand35 117

#define MODEL_SCALE 1.000000
