/* =======================================================================
 *
 * Medic animations.
 *
 * =======================================================================
 */

#define FRAME_walk1 0
#define FRAME_walk2 1
#define FRAME_walk3 2
#define FRAME_walk4 3
#define FRAME_walk5 4
#define FRAME_walk6 5
#define FRAME_walk7 6
#define FRAME_walk8 7
#define FRAME_walk9 8
#define FRAME_walk10 9
#define FRAME_walk11 10
#define FRAME_walk12 11
#define FRAME_wait1 12
#define FRAME_wait2 13
#define FRAME_wait3 14
#define FRAME_wait4 15
#define FRAME_wait5 16
#define FRAME_wait6 17
#define FRAME_wait7 18
#define FRAME_wait8 19
#define FRAME_wait9 20
#define FRAME_wait10 21
#define FRAME_wait11 22
#define FRAME_wait12 23
#define FRAME_wait13 24
#define FRAME_wait14 25
#define FRAME_wait15 26
#define FRAME_wait16 27
#define FRAME_wait17 28
#define FRAME_wait18 29
#define FRAME_wait19 30
#define FRAME_wait20 31
#define FRAME_wait21 32
#define FRAME_wait22 33
#define FRAME_wait23 34
#define FRAME_wait24 35
#define FRAME_wait25 36
#define FRAME_wait26 37
#define FRAME_wait27 38
#define FRAME_wait28 39
#define FRAME_wait29 40
#define FRAME_wait30 41
#define FRAME_wait31 42
#define FRAME_wait32 43
#define FRAME_wait33 44
#define FRAME_wait34 45
#define FRAME_wait35 46
#define FRAME_wait36 47
#define FRAME_wait37 48
#define FRAME_wait38 49
#define FRAME_wait39 50
#define FRAME_wait40 51
#define FRAME_wait41 52
#define FRAME_wait42 53
#define FRAME_wait43 54
#define FRAME_wait44 55
#define FRAME_wait45 56
#define FRAME_wait46 57
#define FRAME_wait47 58
#define FRAME_wait48 59
#define FRAME_wait49 60
#define FRAME_wait50 61
#define FRAME_wait51 62
#define FRAME_wait52 63
#define FRAME_wait53 64
#define FRAME_wait54 65
#define FRAME_wait55 66
#define FRAME_wait56 67
#define FRAME_wait57 68
#define FRAME_wait58 69
#define FRAME_wait59 70
#define FRAME_wait60 71
#define FRAME_wait61 72
#define FRAME_wait62 73
#define FRAME_wait63 74
#define FRAME_wait64 75
#define FRAME_wait65 76
#define FRAME_wait66 77
#define FRAME_wait67 78
#define FRAME_wait68 79
#define FRAME_wait69 80
#define FRAME_wait70 81
#define FRAME_wait71 82
#define FRAME_wait72 83
#define FRAME_wait73 84
#define FRAME_wait74 85
#define FRAME_wait75 86
#define FRAME_wait76 87
#define FRAME_wait77 88
#define FRAME_wait78 89
#define FRAME_wait79 90
#define FRAME_wait80 91
#define FRAME_wait81 92
#define FRAME_wait82 93
#define FRAME_wait83 94
#define FRAME_wait84 95
#define FRAME_wait85 96
#define FRAME_wait86 97
#define FRAME_wait87 98
#define FRAME_wait88 99
#define FRAME_wait89 100
#define FRAME_wait90 101
#define FRAME_run1 102
#define FRAME_run2 103
#define FRAME_run3 104
#define FRAME_run4 105
#define FRAME_run5 106
#define FRAME_run6 107
#define FRAME_paina1 108
#define FRAME_paina2 109
#define FRAME_paina3 110
#define FRAME_paina4 111
#define FRAME_paina5 112
#define FRAME_paina6 113
#define FRAME_paina7 114
#define FRAME_paina8 115
#define FRAME_painb1 116
#define FRAME_painb2 117
#define FRAME_painb3 118
#define FRAME_painb4 119
#define FRAME_painb5 120
#define FRAME_painb6 121
#define FRAME_painb7 122
#define FRAME_painb8 123
#define FRAME_painb9 124
#define FRAME_painb10 125
#define FRAME_painb11 126
#define FRAME_painb12 127
#define FRAME_painb13 128
#define FRAME_painb14 129
#define FRAME_painb15 130
#define FRAME_duck1 131
#define FRAME_duck2 132
#define FRAME_duck3 133
#define FRAME_duck4 134
#define FRAME_duck5 135
#define FRAME_duck6 136
#define FRAME_duck7 137
#define FRAME_duck8 138
#define FRAME_duck9 139
#define FRAME_duck10 140
#define FRAME_duck11 141
#define FRAME_duck12 142
#define FRAME_duck13 143
#define FRAME_duck14 144
#define FRAME_duck15 145
#define FRAME_duck16 146
#define FRAME_death1 147
#define FRAME_death2 148
#define FRAME_death3 149
#define FRAME_death4 150
#define FRAME_death5 151
#define FRAME_death6 152
#define FRAME_death7 153
#define FRAME_death8 154
#define FRAME_death9 155
#define FRAME_death10 156
#define FRAME_death11 157
#define FRAME_death12 158
#define FRAME_death13 159
#define FRAME_death14 160
#define FRAME_death15 161
#define FRAME_death16 162
#define FRAME_death17 163
#define FRAME_death18 164
#define FRAME_death19 165
#define FRAME_death20 166
#define FRAME_death21 167
#define FRAME_death22 168
#define FRAME_death23 169
#define FRAME_death24 170
#define FRAME_death25 171
#define FRAME_death26 172
#define FRAME_death27 173
#define FRAME_death28 174
#define FRAME_death29 175
#define FRAME_death30 176
#define FRAME_attack1 177
#define FRAME_attack2 178
#define FRAME_attack3 179
#define FRAME_attack4 180
#define FRAME_attack5 181
#define FRAME_attack6 182
#define FRAME_attack7 183
#define FRAME_attack8 184
#define FRAME_attack9 185
#define FRAME_attack10 186
#define FRAME_attack11 187
#define FRAME_attack12 188
#define FRAME_attack13 189
#define FRAME_attack14 190
#define FRAME_attack15 191
#define FRAME_attack16 192
#define FRAME_attack17 193
#define FRAME_attack18 194
#define FRAME_attack19 195
#define FRAME_attack20 196
#define FRAME_attack21 197
#define FRAME_attack22 198
#define FRAME_attack23 199
#define FRAME_attack24 200
#define FRAME_attack25 201
#define FRAME_attack26 202
#define FRAME_attack27 203
#define FRAME_attack28 204
#define FRAME_attack29 205
#define FRAME_attack30 206
#define FRAME_attack31 207
#define FRAME_attack32 208
#define FRAME_attack33 209
#define FRAME_attack34 210
#define FRAME_attack35 211
#define FRAME_attack36 212
#define FRAME_attack37 213
#define FRAME_attack38 214
#define FRAME_attack39 215
#define FRAME_attack40 216
#define FRAME_attack41 217
#define FRAME_attack42 218
#define FRAME_attack43 219
#define FRAME_attack44 220
#define FRAME_attack45 221
#define FRAME_attack46 222
#define FRAME_attack47 223
#define FRAME_attack48 224
#define FRAME_attack49 225
#define FRAME_attack50 226
#define FRAME_attack51 227
#define FRAME_attack52 228
#define FRAME_attack53 229
#define FRAME_attack54 230
#define FRAME_attack55 231
#define FRAME_attack56 232
#define FRAME_attack57 233
#define FRAME_attack58 234
#define FRAME_attack59 235
#define FRAME_attack60 236

#define MODEL_SCALE 1.000000
