/*
 * Copyright (C) 1997-2001 Id Software, Inc.
 * Copyright (C) 2011 Yamagi Burmeister
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * =======================================================================
 *
 * Functionpointers to every function in the game.so.
 *
 * =======================================================================
 */

{"ReadLevel", (byte *)ReadLevel},
{"ReadLevelLocals", (byte *)ReadLevelLocals},
{"ReadEdict", (byte *)ReadEdict},
{"WriteLevel", (byte *)WriteLevel},
{"WriteLevelLocals", (byte *)WriteLevelLocals},
{"WriteEdict", (byte *)WriteEdict},
{"ReadGame", (byte *)ReadGame},
{"WriteGame", (byte *)WriteGame},
{"ReadClient", (byte *)ReadClient},
{"WriteClient", (byte *)WriteClient},
{"ReadField", (byte *)ReadField},
{"WriteField2", (byte *)WriteField2},
{"WriteField1", (byte *)WriteField1},
{"FindMmoveByName", (byte *)FindMmoveByName},
{"GetMmoveByAddress", (byte *)GetMmoveByAddress},
{"FindFunctionByName", (byte *)FindFunctionByName},
{"GetFunctionByAddress", (byte *)GetFunctionByAddress},
{"InitGame", (byte *)InitGame},
{"Info_SetValueForKey", (byte *)Info_SetValueForKey},
{"Info_Validate", (byte *)Info_Validate},
{"Info_RemoveKey", (byte *)Info_RemoveKey},
{"Info_ValueForKey", (byte *)Info_ValueForKey},
{"Com_sprintf", (byte *)Com_sprintf},
{"Q_strcasecmp", (byte *)Q_strcasecmp},
{"Q_strncasecmp", (byte *)Q_strncasecmp},
{"Q_stricmp", (byte *)Q_stricmp},
{"Com_PageInMemory", (byte *)Com_PageInMemory},
{"COM_Parse", (byte *)COM_Parse},
{"va", (byte *)va},
{"Swap_Init", (byte *)Swap_Init},
{"FloatNoSwap", (byte *)FloatNoSwap},
{"FloatSwap", (byte *)FloatSwap},
{"LongNoSwap", (byte *)LongNoSwap},
{"LongSwap", (byte *)LongSwap},
{"ShortNoSwap", (byte *)ShortNoSwap},
{"ShortSwap", (byte *)ShortSwap},
{"LittleFloat", (byte *)LittleFloat},
{"BigFloat", (byte *)BigFloat},
{"LittleLong", (byte *)LittleLong},
{"BigLong", (byte *)BigLong},
{"LittleShort", (byte *)LittleShort},
{"BigShort", (byte *)BigShort},
{"COM_DefaultExtension", (byte *)COM_DefaultExtension},
{"COM_FilePath", (byte *)COM_FilePath},
{"COM_FileBase", (byte *)COM_FileBase},
{"COM_FileExtension", (byte *)COM_FileExtension},
{"COM_StripExtension", (byte *)COM_StripExtension},
{"COM_SkipPath", (byte *)COM_SkipPath},
{"Q_log2", (byte *)Q_log2},
{"VectorScale", (byte *)VectorScale},
{"VectorInverse", (byte *)VectorInverse},
{"VectorLength", (byte *)VectorLength},
{"CrossProduct", (byte *)CrossProduct},
{"_VectorCopy", (byte *)_VectorCopy},
{"_VectorAdd", (byte *)_VectorAdd},
{"_VectorSubtract", (byte *)_VectorSubtract},
{"_DotProduct", (byte *)_DotProduct},
{"VectorMA", (byte *)VectorMA},
{"VectorNormalize2", (byte *)VectorNormalize2},
{"VectorNormalize", (byte *)VectorNormalize},
{"VectorCompare", (byte *)VectorCompare},
{"AddPointToBounds", (byte *)AddPointToBounds},
{"ClearBounds", (byte *)ClearBounds},
{"BoxOnPlaneSide2", (byte *)BoxOnPlaneSide2},
{"anglemod", (byte *)anglemod},
{"LerpAngle", (byte *)LerpAngle},
{"Q_fabs", (byte *)Q_fabs},
{"R_ConcatTransforms", (byte *)R_ConcatTransforms},
{"R_ConcatRotations", (byte *)R_ConcatRotations},
{"PerpendicularVector", (byte *)PerpendicularVector},
{"ProjectPointOnPlane", (byte *)ProjectPointOnPlane},
{"AngleVectors", (byte *)AngleVectors},
{"RotatePointAroundVector", (byte *)RotatePointAroundVector},
{"Weapon_Trap", (byte *)Weapon_Trap},
{"weapon_trap_fire", (byte *)weapon_trap_fire},
{"Weapon_Phalanx", (byte *)Weapon_Phalanx},
{"weapon_phalanx_fire", (byte *)weapon_phalanx_fire},
{"Weapon_Ionripper", (byte *)Weapon_Ionripper},
{"weapon_ionripper_fire", (byte *)weapon_ionripper_fire},
{"Weapon_BFG", (byte *)Weapon_BFG},
{"weapon_bfg_fire", (byte *)weapon_bfg_fire},
{"Weapon_Railgun", (byte *)Weapon_Railgun},
{"weapon_railgun_fire", (byte *)weapon_railgun_fire},
{"Weapon_SuperShotgun", (byte *)Weapon_SuperShotgun},
{"weapon_supershotgun_fire", (byte *)weapon_supershotgun_fire},
{"Weapon_Shotgun", (byte *)Weapon_Shotgun},
{"weapon_shotgun_fire", (byte *)weapon_shotgun_fire},
{"Weapon_Chaingun", (byte *)Weapon_Chaingun},
{"Chaingun_Fire", (byte *)Chaingun_Fire},
{"Weapon_Machinegun", (byte *)Weapon_Machinegun},
{"Machinegun_Fire", (byte *)Machinegun_Fire},
{"Weapon_HyperBlaster", (byte *)Weapon_HyperBlaster},
{"Weapon_HyperBlaster_Fire", (byte *)Weapon_HyperBlaster_Fire},
{"Weapon_Blaster", (byte *)Weapon_Blaster},
{"Weapon_Blaster_Fire", (byte *)Weapon_Blaster_Fire},
{"Blaster_Fire", (byte *)Blaster_Fire},
{"Weapon_RocketLauncher", (byte *)Weapon_RocketLauncher},
{"Weapon_RocketLauncher_Fire", (byte *)Weapon_RocketLauncher_Fire},
{"Weapon_GrenadeLauncher", (byte *)Weapon_GrenadeLauncher},
{"weapon_grenadelauncher_fire", (byte *)weapon_grenadelauncher_fire},
{"Weapon_Grenade", (byte *)Weapon_Grenade},
{"weapon_grenade_fire", (byte *)weapon_grenade_fire},
{"Weapon_Generic", (byte *)Weapon_Generic},
{"Drop_Weapon", (byte *)Drop_Weapon},
{"Use_Weapon2", (byte *)Use_Weapon2},
{"Use_Weapon", (byte *)Use_Weapon},
{"Think_Weapon", (byte *)Think_Weapon},
{"NoAmmoWeaponChange", (byte *)NoAmmoWeaponChange},
{"ChangeWeapon", (byte *)ChangeWeapon},
{"Pickup_Weapon", (byte *)Pickup_Weapon},
{"PlayerNoise", (byte *)PlayerNoise},
{"P_ProjectSource", (byte *)P_ProjectSource},
{"ClientEndServerFrame", (byte *)ClientEndServerFrame},
{"G_SetClientFrame", (byte *)G_SetClientFrame},
{"G_SetClientSound", (byte *)G_SetClientSound},
{"G_SetClientEvent", (byte *)G_SetClientEvent},
{"G_SetClientEffects", (byte *)G_SetClientEffects},
{"P_WorldEffects", (byte *)P_WorldEffects},
{"P_FallingDamage", (byte *)P_FallingDamage},
{"SV_CalcBlend", (byte *)SV_CalcBlend},
{"SV_AddBlend", (byte *)SV_AddBlend},
{"SV_CalcGunOffset", (byte *)SV_CalcGunOffset},
{"SV_CalcViewOffset", (byte *)SV_CalcViewOffset},
{"P_DamageFeedback", (byte *)P_DamageFeedback},
{"SV_CalcRoll", (byte *)SV_CalcRoll},
{"PlayerTrail_LastSpot", (byte *)PlayerTrail_LastSpot},
{"PlayerTrail_PickNext", (byte *)PlayerTrail_PickNext},
{"PlayerTrail_PickFirst", (byte *)PlayerTrail_PickFirst},
{"PlayerTrail_New", (byte *)PlayerTrail_New},
{"PlayerTrail_Add", (byte *)PlayerTrail_Add},
{"PlayerTrail_Init", (byte *)PlayerTrail_Init},
{"G_SetSpectatorStats", (byte *)G_SetSpectatorStats},
{"G_CheckChaseStats", (byte *)G_CheckChaseStats},
{"G_SetStats", (byte *)G_SetStats},
{"InventoryMessage", (byte *)InventoryMessage},
{"HelpComputerMessage", (byte *)HelpComputerMessage},
{"DeathmatchScoreboardMessage", (byte *)DeathmatchScoreboardMessage},
{"BeginIntermission", (byte *)BeginIntermission},
{"MoveClientToIntermission", (byte *)MoveClientToIntermission},
{"ClientBeginServerFrame", (byte *)ClientBeginServerFrame},
{"ClientThink", (byte *)ClientThink},
{"PrintPmove", (byte *)PrintPmove},
{"CheckBlock", (byte *)CheckBlock},
{"PM_trace", (byte *)PM_trace},
{"ClientDisconnect", (byte *)ClientDisconnect},
{"ClientConnect", (byte *)ClientConnect},
{"ClientUserinfoChanged", (byte *)ClientUserinfoChanged},
{"ClientBegin", (byte *)ClientBegin},
{"ClientBeginDeathmatch", (byte *)ClientBeginDeathmatch},
{"PutClientInServer", (byte *)PutClientInServer},
{"spectator_respawn", (byte *)spectator_respawn},
{"respawn", (byte *)respawn},
{"CopyToBodyQue", (byte *)CopyToBodyQue},
{"body_die", (byte *)body_die},
{"InitBodyQue", (byte *)InitBodyQue},
{"SelectSpawnPoint", (byte *)SelectSpawnPoint},
{"SelectCoopSpawnPoint", (byte *)SelectCoopSpawnPoint},
{"SelectDeathmatchSpawnPoint", (byte *)SelectDeathmatchSpawnPoint},
{"SelectFarthestDeathmatchSpawnPoint", (byte *)SelectFarthestDeathmatchSpawnPoint},
{"SelectRandomDeathmatchSpawnPoint", (byte *)SelectRandomDeathmatchSpawnPoint},
{"PlayersRangeFromSpot", (byte *)PlayersRangeFromSpot},
{"FetchClientEntData", (byte *)FetchClientEntData},
{"SaveClientData", (byte *)SaveClientData},
{"InitClientResp", (byte *)InitClientResp},
{"InitClientPersistant", (byte *)InitClientPersistant},
{"player_die", (byte *)player_die},
{"LookAtKiller", (byte *)LookAtKiller},
{"TossClientWeapon", (byte *)TossClientWeapon},
{"ClientObituary", (byte *)ClientObituary},
{"IsNeutral", (byte *)IsNeutral},
{"IsFemale", (byte *)IsFemale},
{"player_pain", (byte *)player_pain},
{"SP_info_player_intermission", (byte *)SP_info_player_intermission},
{"SP_info_player_coop", (byte *)SP_info_player_coop},
{"SP_info_player_deathmatch", (byte *)SP_info_player_deathmatch},
{"SP_info_player_start", (byte *)SP_info_player_start},
{"SP_CreateCoopSpots", (byte *)SP_CreateCoopSpots},
{"SP_FixCoopSpots", (byte *)SP_FixCoopSpots},
{"SP_monster_tank", (byte *)SP_monster_tank},
{"tank_die", (byte *)tank_die},
{"tank_dead", (byte *)tank_dead},
{"tank_attack", (byte *)tank_attack},
{"tank_doattack_rocket", (byte *)tank_doattack_rocket},
{"tank_refire_rocket", (byte *)tank_refire_rocket},
{"tank_poststrike", (byte *)tank_poststrike},
{"tank_reattack_blaster", (byte *)tank_reattack_blaster},
{"TankMachineGun", (byte *)TankMachineGun},
{"TankRocket", (byte *)TankRocket},
{"TankStrike", (byte *)TankStrike},
{"TankBlaster", (byte *)TankBlaster},
{"tank_pain", (byte *)tank_pain},
{"tank_run", (byte *)tank_run},
{"tank_walk", (byte *)tank_walk},
{"tank_stand", (byte *)tank_stand},
{"tank_idle", (byte *)tank_idle},
{"tank_windup", (byte *)tank_windup},
{"tank_thud", (byte *)tank_thud},
{"tank_footstep", (byte *)tank_footstep},
{"tank_sight", (byte *)tank_sight},
{"SP_monster_supertank", (byte *)SP_monster_supertank},
{"supertank_die", (byte *)supertank_die},
{"BossExplode", (byte *)BossExplode},
{"supertank_dead", (byte *)supertank_dead},
{"supertank_attack", (byte *)supertank_attack},
{"supertankMachineGun", (byte *)supertankMachineGun},
{"supertankRocket", (byte *)supertankRocket},
{"supertank_pain", (byte *)supertank_pain},
{"supertank_reattack1", (byte *)supertank_reattack1},
{"supertank_run", (byte *)supertank_run},
{"supertank_walk", (byte *)supertank_walk},
{"supertank_forward", (byte *)supertank_forward},
{"supertank_stand", (byte *)supertank_stand},
{"supertank_search", (byte *)supertank_search},
{"TreadSound", (byte *)TreadSound},
{"SP_monster_soldier_lasergun", (byte *)SP_monster_soldier_lasergun},
{"SP_monster_soldier_hypergun", (byte *)SP_monster_soldier_hypergun},
{"SP_monster_soldier_ripper", (byte *)SP_monster_soldier_ripper},
{"SP_monster_soldier_h", (byte *)SP_monster_soldier_h},
{"soldierh_die", (byte *)soldierh_die},
{"soldierh_dead", (byte *)soldierh_dead},
{"soldierh_fire7", (byte *)soldierh_fire7},
{"soldierh_fire6", (byte *)soldierh_fire6},
{"soldierh_dodge", (byte *)soldierh_dodge},
{"soldierh_duck_hold", (byte *)soldierh_duck_hold},
{"soldierh_sight", (byte *)soldierh_sight},
{"soldierh_attack", (byte *)soldierh_attack},
{"soldierh_attack6_refire", (byte *)soldierh_attack6_refire},
{"soldierh_fire8", (byte *)soldierh_fire8},
{"soldierh_fire4", (byte *)soldierh_fire4},
{"soldierh_attack3_refire", (byte *)soldierh_attack3_refire},
{"soldierh_fire3", (byte *)soldierh_fire3},
{"soldierh_duck_up", (byte *)soldierh_duck_up},
{"soldierh_duck_down", (byte *)soldierh_duck_down},
{"soldierh_attack2_refire2", (byte *)soldierh_attack2_refire2},
{"soldierh_attack2_refire1", (byte *)soldierh_attack2_refire1},
{"soldierh_fire2", (byte *)soldierh_fire2},
{"soldierh_ripper2", (byte *)soldierh_ripper2},
{"soldierh_hyper_refire2", (byte *)soldierh_hyper_refire2},
{"soldierh_hyper_sound", (byte *)soldierh_hyper_sound},
{"soldierh_attack1_refire2", (byte *)soldierh_attack1_refire2},
{"soldierh_attack1_refire1", (byte *)soldierh_attack1_refire1},
{"soldierh_fire1", (byte *)soldierh_fire1},
{"soldierh_ripper1", (byte *)soldierh_ripper1},
{"soldierh_hyper_refire1", (byte *)soldierh_hyper_refire1},
{"soldierh_fire", (byte *)soldierh_fire},
{"soldierh_laserbeam", (byte *)soldierh_laserbeam},
{"soldierh_pain", (byte *)soldierh_pain},
{"soldierh_run", (byte *)soldierh_run},
{"soldierh_walk", (byte *)soldierh_walk},
{"soldierh_walk1_random", (byte *)soldierh_walk1_random},
{"soldierh_stand", (byte *)soldierh_stand},
{"soldierh_cock", (byte *)soldierh_cock},
{"soldierh_idle", (byte *)soldierh_idle},
{"SP_monster_soldier_ss", (byte *)SP_monster_soldier_ss},
{"SP_monster_soldier", (byte *)SP_monster_soldier},
{"SP_monster_soldier_light", (byte *)SP_monster_soldier_light},
{"SP_monster_soldier_x", (byte *)SP_monster_soldier_x},
{"soldier_footstep", (byte *)soldier_footstep},
{"soldier_die", (byte *)soldier_die},
{"soldier_dead", (byte *)soldier_dead},
{"soldier_fire7", (byte *)soldier_fire7},
{"soldier_fire6", (byte *)soldier_fire6},
{"soldier_dodge", (byte *)soldier_dodge},
{"soldier_duck_hold", (byte *)soldier_duck_hold},
{"soldier_sight", (byte *)soldier_sight},
{"soldier_attack", (byte *)soldier_attack},
{"soldier_attack6_refire", (byte *)soldier_attack6_refire},
{"soldier_fire8", (byte *)soldier_fire8},
{"soldier_fire4", (byte *)soldier_fire4},
{"soldier_attack3_refire", (byte *)soldier_attack3_refire},
{"soldier_fire3", (byte *)soldier_fire3},
{"soldier_duck_up", (byte *)soldier_duck_up},
{"soldier_duck_down", (byte *)soldier_duck_down},
{"soldier_attack2_refire2", (byte *)soldier_attack2_refire2},
{"soldier_attack2_refire1", (byte *)soldier_attack2_refire1},
{"soldier_fire2", (byte *)soldier_fire2},
{"soldier_attack1_refire2", (byte *)soldier_attack1_refire2},
{"soldier_attack1_refire1", (byte *)soldier_attack1_refire1},
{"soldier_fire1", (byte *)soldier_fire1},
{"soldier_fire", (byte *)soldier_fire},
{"soldier_pain", (byte *)soldier_pain},
{"soldier_run", (byte *)soldier_run},
{"soldier_walk", (byte *)soldier_walk},
{"soldier_walk1_random", (byte *)soldier_walk1_random},
{"soldier_stand", (byte *)soldier_stand},
{"soldier_cock", (byte *)soldier_cock},
{"soldier_idle", (byte *)soldier_idle},
{"SP_monster_parasite", (byte *)SP_monster_parasite},
{"parasite_die", (byte *)parasite_die},
{"parasite_dead", (byte *)parasite_dead},
{"parasite_attack", (byte *)parasite_attack},
{"parasite_drain_attack", (byte *)parasite_drain_attack},
{"parasite_drain_attack_ok", (byte *)parasite_drain_attack_ok},
{"parasite_pain", (byte *)parasite_pain},
{"parasite_walk", (byte *)parasite_walk},
{"parasite_start_walk", (byte *)parasite_start_walk},
{"parasite_run", (byte *)parasite_run},
{"parasite_start_run", (byte *)parasite_start_run},
{"parasite_stand", (byte *)parasite_stand},
{"parasite_idle", (byte *)parasite_idle},
{"parasite_refidget", (byte *)parasite_refidget},
{"parasite_do_fidget", (byte *)parasite_do_fidget},
{"parasite_end_fidget", (byte *)parasite_end_fidget},
{"parasite_search", (byte *)parasite_search},
{"parasite_scratch", (byte *)parasite_scratch},
{"parasite_tap", (byte *)parasite_tap},
{"parasite_sight", (byte *)parasite_sight},
{"parasite_reel_in", (byte *)parasite_reel_in},
{"parasite_launch", (byte *)parasite_launch},
{"SP_monster_mutant", (byte *)SP_monster_mutant},
{"mutant_die", (byte *)mutant_die},
{"mutant_dead", (byte *)mutant_dead},
{"mutant_pain", (byte *)mutant_pain},
{"mutant_checkattack", (byte *)mutant_checkattack},
{"mutant_check_jump", (byte *)mutant_check_jump},
{"mutant_check_melee", (byte *)mutant_check_melee},
{"mutant_jump", (byte *)mutant_jump},
{"mutant_check_landing", (byte *)mutant_check_landing},
{"mutant_jump_takeoff", (byte *)mutant_jump_takeoff},
{"mutant_jump_touch", (byte *)mutant_jump_touch},
{"mutant_melee", (byte *)mutant_melee},
{"mutant_check_refire", (byte *)mutant_check_refire},
{"mutant_hit_right", (byte *)mutant_hit_right},
{"mutant_hit_left", (byte *)mutant_hit_left},
{"mutant_run", (byte *)mutant_run},
{"mutant_walk", (byte *)mutant_walk},
{"mutant_walk_loop", (byte *)mutant_walk_loop},
{"mutant_idle", (byte *)mutant_idle},
{"mutant_idle_loop", (byte *)mutant_idle_loop},
{"mutant_stand", (byte *)mutant_stand},
{"mutant_swing", (byte *)mutant_swing},
{"mutant_search", (byte *)mutant_search},
{"mutant_sight", (byte *)mutant_sight},
{"mutant_step", (byte *)mutant_step},
{"M_walkmove", (byte *)M_walkmove},
{"M_MoveToGoal", (byte *)M_MoveToGoal},
{"SV_CloseEnough", (byte *)SV_CloseEnough},
{"SV_NewChaseDir", (byte *)SV_NewChaseDir},
{"SV_FixCheckBottom", (byte *)SV_FixCheckBottom},
{"SV_StepDirection", (byte *)SV_StepDirection},
{"M_ChangeYaw", (byte *)M_ChangeYaw},
{"SV_movestep", (byte *)SV_movestep},
{"M_CheckBottom", (byte *)M_CheckBottom},
{"SP_monster_medic", (byte *)SP_monster_medic},
{"medic_footstep", (byte *)medic_footstep},
{"medic_checkattack", (byte *)medic_checkattack},
{"medic_attack", (byte *)medic_attack},
{"medic_hook_retract", (byte *)medic_hook_retract},
{"medic_cable_attack", (byte *)medic_cable_attack},
{"medic_hook_launch", (byte *)medic_hook_launch},
{"medic_continue", (byte *)medic_continue},
{"medic_dodge", (byte *)medic_dodge},
{"medic_duck_up", (byte *)medic_duck_up},
{"medic_duck_hold", (byte *)medic_duck_hold},
{"medic_duck_down", (byte *)medic_duck_down},
{"medic_die", (byte *)medic_die},
{"medic_dead", (byte *)medic_dead},
{"medic_fire_blaster", (byte *)medic_fire_blaster},
{"medic_pain", (byte *)medic_pain},
{"medic_run", (byte *)medic_run},
{"medic_walk", (byte *)medic_walk},
{"medic_stand", (byte *)medic_stand},
{"medic_sight", (byte *)medic_sight},
{"medic_search", (byte *)medic_search},
{"medic_idle", (byte *)medic_idle},
{"medic_FindDeadMonster", (byte *)medic_FindDeadMonster},
{"SP_misc_insane", (byte *)SP_misc_insane},
{"insane_footstep", (byte *)insane_footstep},
{"insane_die", (byte *)insane_die},
{"insane_dead", (byte *)insane_dead},
{"insane_stand", (byte *)insane_stand},
{"insane_checkup", (byte *)insane_checkup},
{"insane_checkdown", (byte *)insane_checkdown},
{"insane_onground", (byte *)insane_onground},
{"insane_pain", (byte *)insane_pain},
{"insane_run", (byte *)insane_run},
{"insane_walk", (byte *)insane_walk},
{"insane_cross", (byte *)insane_cross},
{"insane_scream", (byte *)insane_scream},
{"insane_moan", (byte *)insane_moan},
{"insane_shake", (byte *)insane_shake},
{"insane_fist", (byte *)insane_fist},
{"SP_monster_infantry", (byte *)SP_monster_infantry},
{"infantry_footstep", (byte *)infantry_footstep},
{"infantry_attack", (byte *)infantry_attack},
{"infantry_smack", (byte *)infantry_smack},
{"infantry_swing", (byte *)infantry_swing},
{"infantry_fire", (byte *)infantry_fire},
{"infantry_cock_gun", (byte *)infantry_cock_gun},
{"infantry_set_firetime", (byte *)infantry_set_firetime},
{"infantry_dodge", (byte *)infantry_dodge},
{"infantry_duck_up", (byte *)infantry_duck_up},
{"infantry_duck_hold", (byte *)infantry_duck_hold},
{"infantry_duck_down", (byte *)infantry_duck_down},
{"infantry_die", (byte *)infantry_die},
{"infantry_dead", (byte *)infantry_dead},
{"infantry_sight", (byte *)infantry_sight},
{"InfantryMachineGun", (byte *)InfantryMachineGun},
{"infantry_pain", (byte *)infantry_pain},
{"infantry_run", (byte *)infantry_run},
{"infantry_walk", (byte *)infantry_walk},
{"infantry_fidget", (byte *)infantry_fidget},
{"infantry_stand", (byte *)infantry_stand},
{"SP_monster_hover", (byte *)SP_monster_hover},
{"hover_die", (byte *)hover_die},
{"hover_dead", (byte *)hover_dead},
{"hover_deadthink", (byte *)hover_deadthink},
{"hover_pain", (byte *)hover_pain},
{"hover_attack", (byte *)hover_attack},
{"hover_start_attack", (byte *)hover_start_attack},
{"hover_walk", (byte *)hover_walk},
{"hover_run", (byte *)hover_run},
{"hover_stand", (byte *)hover_stand},
{"hover_fire_blaster", (byte *)hover_fire_blaster},
{"hover_reattack", (byte *)hover_reattack},
{"hover_search", (byte *)hover_search},
{"hover_sight", (byte *)hover_sight},
{"SP_monster_gunner", (byte *)SP_monster_gunner},
{"gunner_footstep", (byte *)gunner_footstep},
{"gunner_refire_chain", (byte *)gunner_refire_chain},
{"gunner_fire_chain", (byte *)gunner_fire_chain},
{"gunner_attack", (byte *)gunner_attack},
{"GunnerGrenade", (byte *)GunnerGrenade},
{"GunnerFire", (byte *)GunnerFire},
{"gunner_opengun", (byte *)gunner_opengun},
{"gunner_dodge", (byte *)gunner_dodge},
{"gunner_duck_up", (byte *)gunner_duck_up},
{"gunner_duck_hold", (byte *)gunner_duck_hold},
{"gunner_duck_down", (byte *)gunner_duck_down},
{"gunner_die", (byte *)gunner_die},
{"gunner_dead", (byte *)gunner_dead},
{"gunner_pain", (byte *)gunner_pain},
{"gunner_runandshoot", (byte *)gunner_runandshoot},
{"gunner_run", (byte *)gunner_run},
{"gunner_walk", (byte *)gunner_walk},
{"gunner_stand", (byte *)gunner_stand},
{"gunner_fidget", (byte *)gunner_fidget},
{"gunner_search", (byte *)gunner_search},
{"gunner_sight", (byte *)gunner_sight},
{"gunner_idlesound", (byte *)gunner_idlesound},
{"SP_monster_gladiator", (byte *)SP_monster_gladiator},
{"gladiator_footstep", (byte *)gladiator_footstep},
{"gladiator_die", (byte *)gladiator_die},
{"gladiator_dead", (byte *)gladiator_dead},
{"gladiator_pain", (byte *)gladiator_pain},
{"gladiator_attack", (byte *)gladiator_attack},
{"GladiatorGun", (byte *)GladiatorGun},
{"gladiator_melee", (byte *)gladiator_melee},
{"GaldiatorMelee", (byte *)GaldiatorMelee},
{"gladiator_run", (byte *)gladiator_run},
{"gladiator_walk", (byte *)gladiator_walk},
{"gladiator_stand", (byte *)gladiator_stand},
{"gladiator_cleaver_swing", (byte *)gladiator_cleaver_swing},
{"gladiator_search", (byte *)gladiator_search},
{"gladiator_sight", (byte *)gladiator_sight},
{"gladiator_idle", (byte *)gladiator_idle},
{"SP_monster_gladb", (byte *)SP_monster_gladb},
{"gladb_die", (byte *)gladb_die},
{"gladb_dead", (byte *)gladb_dead},
{"gladb_pain", (byte *)gladb_pain},
{"gladb_attack", (byte *)gladb_attack},
{"gladbGun_check", (byte *)gladbGun_check},
{"gladbGun", (byte *)gladbGun},
{"gladb_melee", (byte *)gladb_melee},
{"GladbMelee", (byte *)GladbMelee},
{"gladb_run", (byte *)gladb_run},
{"gladb_walk", (byte *)gladb_walk},
{"gladb_stand", (byte *)gladb_stand},
{"gladb_cleaver_swing", (byte *)gladb_cleaver_swing},
{"gladb_search", (byte *)gladb_search},
{"gladb_sight", (byte *)gladb_sight},
{"gladb_idle", (byte *)gladb_idle},
{"land_to_water", (byte *)land_to_water},
{"water_to_land", (byte *)water_to_land},
{"SP_monster_gekk", (byte *)SP_monster_gekk},
{"gekk_dodge", (byte *)gekk_dodge},
{"gekk_duck_hold", (byte *)gekk_duck_hold},
{"gekk_duck_up", (byte *)gekk_duck_up},
{"gekk_duck_down", (byte *)gekk_duck_down},
{"gekk_die", (byte *)gekk_die},
{"isgibfest", (byte *)isgibfest},
{"gekk_gibfest", (byte *)gekk_gibfest},
{"gekk_dead", (byte *)gekk_dead},
{"gekk_pain", (byte *)gekk_pain},
{"gekk_jump", (byte *)gekk_jump},
{"gekk_check_landing", (byte *)gekk_check_landing},
{"gekk_stop_skid", (byte *)gekk_stop_skid},
{"gekk_jump_takeoff2", (byte *)gekk_jump_takeoff2},
{"gekk_jump_takeoff", (byte *)gekk_jump_takeoff},
{"gekk_jump_touch", (byte *)gekk_jump_touch},
{"gekk_melee", (byte *)gekk_melee},
{"gekk_preattack", (byte *)gekk_preattack},
{"gekk_bite", (byte *)gekk_bite},
{"gekk_check_underwater", (byte *)gekk_check_underwater},
{"reloogie", (byte *)reloogie},
{"loogie", (byte *)loogie},
{"fire_loogie", (byte *)fire_loogie},
{"loogie_touch", (byte *)loogie_touch},
{"gekk_check_refire", (byte *)gekk_check_refire},
{"gekk_hit_right", (byte *)gekk_hit_right},
{"gekk_hit_left", (byte *)gekk_hit_left},
{"gekk_run", (byte *)gekk_run},
{"gekk_run_start", (byte *)gekk_run_start},
{"gekk_walk", (byte *)gekk_walk},
{"gekk_idle", (byte *)gekk_idle},
{"gekk_idle_loop", (byte *)gekk_idle_loop},
{"gekk_stand", (byte *)gekk_stand},
{"gekk_swim", (byte *)gekk_swim},
{"gekk_swim_loop", (byte *)gekk_swim_loop},
{"ai_stand2", (byte *)ai_stand2},
{"gekk_face", (byte *)gekk_face},
{"gekk_swing", (byte *)gekk_swing},
{"gekk_search", (byte *)gekk_search},
{"gekk_sight", (byte *)gekk_sight},
{"gekk_step", (byte *)gekk_step},
{"gekk_checkattack", (byte *)gekk_checkattack},
{"gekk_check_jump_close", (byte *)gekk_check_jump_close},
{"gekk_check_jump", (byte *)gekk_check_jump},
{"gekk_check_melee", (byte *)gekk_check_melee},
{"SP_monster_flyer", (byte *)SP_monster_flyer},
{"flyer_die", (byte *)flyer_die},
{"flyer_pain", (byte *)flyer_pain},
{"flyer_check_melee", (byte *)flyer_check_melee},
{"flyer_melee", (byte *)flyer_melee},
{"flyer_nextmove", (byte *)flyer_nextmove},
{"flyer_setstart", (byte *)flyer_setstart},
{"flyer_attack", (byte *)flyer_attack},
{"flyer_loop_melee", (byte *)flyer_loop_melee},
{"flyer_slash_right", (byte *)flyer_slash_right},
{"flyer_slash_left", (byte *)flyer_slash_left},
{"flyer_fireright", (byte *)flyer_fireright},
{"flyer_fireleft", (byte *)flyer_fireleft},
{"flyer_fire", (byte *)flyer_fire},
{"flyer_start", (byte *)flyer_start},
{"flyer_stop", (byte *)flyer_stop},
{"flyer_stand", (byte *)flyer_stand},
{"flyer_walk", (byte *)flyer_walk},
{"flyer_run", (byte *)flyer_run},
{"flyer_pop_blades", (byte *)flyer_pop_blades},
{"flyer_idle", (byte *)flyer_idle},
{"flyer_sight", (byte *)flyer_sight},
{"SP_monster_floater", (byte *)SP_monster_floater},
{"floater_die", (byte *)floater_die},
{"floater_dead", (byte *)floater_dead},
{"floater_pain", (byte *)floater_pain},
{"floater_melee", (byte *)floater_melee},
{"floater_attack", (byte *)floater_attack},
{"floater_zap", (byte *)floater_zap},
{"floater_wham", (byte *)floater_wham},
{"floater_walk", (byte *)floater_walk},
{"floater_run", (byte *)floater_run},
{"floater_stand", (byte *)floater_stand},
{"floater_fire_blaster", (byte *)floater_fire_blaster},
{"floater_idle", (byte *)floater_idle},
{"floater_sight", (byte *)floater_sight},
{"SP_monster_flipper", (byte *)SP_monster_flipper},
{"flipper_die", (byte *)flipper_die},
{"flipper_sight", (byte *)flipper_sight},
{"flipper_dead", (byte *)flipper_dead},
{"flipper_pain", (byte *)flipper_pain},
{"flipper_melee", (byte *)flipper_melee},
{"flipper_preattack", (byte *)flipper_preattack},
{"flipper_bite", (byte *)flipper_bite},
{"flipper_start_run", (byte *)flipper_start_run},
{"flipper_walk", (byte *)flipper_walk},
{"flipper_run", (byte *)flipper_run},
{"flipper_run_loop", (byte *)flipper_run_loop},
{"flipper_stand", (byte *)flipper_stand},
{"SP_monster_fixbot", (byte *)SP_monster_fixbot},
{"bot_goal_think", (byte *)bot_goal_think},
{"fixbot_die", (byte *)fixbot_die},
{"fixbot_dead", (byte *)fixbot_dead},
{"fixbot_pain", (byte *)fixbot_pain},
{"fixbot_attack", (byte *)fixbot_attack},
{"fixbot_start_attack", (byte *)fixbot_start_attack},
{"fixbot_walk", (byte *)fixbot_walk},
{"fixbot_run", (byte *)fixbot_run},
{"fixbot_stand", (byte *)fixbot_stand},
{"fixbot_fire_blaster", (byte *)fixbot_fire_blaster},
{"fixbot_fire_welder", (byte *)fixbot_fire_welder},
{"ai_move2", (byte *)ai_move2},
{"weldstate", (byte *)weldstate},
{"fixbot_fire_laser", (byte *)fixbot_fire_laser},
{"check_telefrag", (byte *)check_telefrag},
{"ai_movetogoal", (byte *)ai_movetogoal},
{"go_roam", (byte *)go_roam},
{"ai_facing", (byte *)ai_facing},
{"fly_vertical2", (byte *)fly_vertical2},
{"fly_vertical", (byte *)fly_vertical},
{"blastoff", (byte *)blastoff},
{"use_scanner", (byte *)use_scanner},
{"roam_goal", (byte *)roam_goal},
{"change_to_roam", (byte *)change_to_roam},
{"takeoff_goal", (byte *)takeoff_goal},
{"landing_goal", (byte *)landing_goal},
{"fixbot_search", (byte *)fixbot_search},
{"fixbot_FindDeadMonster", (byte *)fixbot_FindDeadMonster},
{"crand", (byte *)crand},
{"SP_monster_chick_heat", (byte *)SP_monster_chick_heat},
{"SP_monster_chick", (byte *)SP_monster_chick},
{"chick_footstep", (byte *)chick_footstep},
{"chick_sight", (byte *)chick_sight},
{"chick_attack", (byte *)chick_attack},
{"chick_melee", (byte *)chick_melee},
{"chick_slash", (byte *)chick_slash},
{"chick_reslash", (byte *)chick_reslash},
{"chick_attack1", (byte *)chick_attack1},
{"chick_rerocket", (byte *)chick_rerocket},
{"ChickReload", (byte *)ChickReload},
{"Chick_PreAttack1", (byte *)Chick_PreAttack1},
{"ChickRocket", (byte *)ChickRocket},
{"ChickSlash", (byte *)ChickSlash},
{"chick_dodge", (byte *)chick_dodge},
{"chick_duck_up", (byte *)chick_duck_up},
{"chick_duck_hold", (byte *)chick_duck_hold},
{"chick_duck_down", (byte *)chick_duck_down},
{"chick_die", (byte *)chick_die},
{"chick_dead", (byte *)chick_dead},
{"chick_pain", (byte *)chick_pain},
{"chick_run", (byte *)chick_run},
{"chick_walk", (byte *)chick_walk},
{"chick_stand", (byte *)chick_stand},
{"chick_fidget", (byte *)chick_fidget},
{"ChickMoan", (byte *)ChickMoan},
{"SP_monster_brain", (byte *)SP_monster_brain},
{"brain_footstep", (byte *)brain_footstep},
{"brain_die", (byte *)brain_die},
{"brain_dead", (byte *)brain_dead},
{"brain_pain", (byte *)brain_pain},
{"brain_run", (byte *)brain_run},
{"brain_attack", (byte *)brain_attack},
{"brain_laserbeam_reattack", (byte *)brain_laserbeam_reattack},
{"brain_laserbeam", (byte *)brain_laserbeam},
{"brain_tounge_attack", (byte *)brain_tounge_attack},
{"brain_tounge_attack_ok", (byte *)brain_tounge_attack_ok},
{"brain_melee", (byte *)brain_melee},
{"brain_chest_closed", (byte *)brain_chest_closed},
{"brain_tentacle_attack", (byte *)brain_tentacle_attack},
{"brain_chest_open", (byte *)brain_chest_open},
{"brain_hit_left", (byte *)brain_hit_left},
{"brain_swing_left", (byte *)brain_swing_left},
{"brain_hit_right", (byte *)brain_hit_right},
{"brain_swing_right", (byte *)brain_swing_right},
{"brain_dodge", (byte *)brain_dodge},
{"brain_duck_up", (byte *)brain_duck_up},
{"brain_duck_hold", (byte *)brain_duck_hold},
{"brain_duck_down", (byte *)brain_duck_down},
{"brain_walk", (byte *)brain_walk},
{"brain_idle", (byte *)brain_idle},
{"brain_stand", (byte *)brain_stand},
{"brain_search", (byte *)brain_search},
{"brain_sight", (byte *)brain_sight},
{"SP_monster_boss5", (byte *)SP_monster_boss5},
{"boss5_die", (byte *)boss5_die},
{"BossExplode2", (byte *)BossExplode2},
{"boss5_dead", (byte *)boss5_dead},
{"boss5_attack", (byte *)boss5_attack},
{"boss5MachineGun", (byte *)boss5MachineGun},
{"boss5Rocket", (byte *)boss5Rocket},
{"boss5_pain", (byte *)boss5_pain},
{"boss5_reattack1", (byte *)boss5_reattack1},
{"boss5_run", (byte *)boss5_run},
{"boss5_walk", (byte *)boss5_walk},
{"boss5_forward", (byte *)boss5_forward},
{"boss5_stand", (byte *)boss5_stand},
{"boss5_search", (byte *)boss5_search},
{"TreadSound2", (byte *)TreadSound2},
{"MakronToss", (byte *)MakronToss},
{"MakronSpawn", (byte *)MakronSpawn},
{"SP_monster_makron", (byte *)SP_monster_makron},
{"MakronPrecache", (byte *)MakronPrecache},
{"Makron_CheckAttack", (byte *)Makron_CheckAttack},
{"makron_die", (byte *)makron_die},
{"makron_torso_die", (byte *)makron_torso_die},
{"makron_dead", (byte *)makron_dead},
{"makron_torso", (byte *)makron_torso},
{"makron_torso_think", (byte *)makron_torso_think},
{"makron_attack", (byte *)makron_attack},
{"makron_sight", (byte *)makron_sight},
{"makron_pain", (byte *)makron_pain},
{"MakronHyperblaster", (byte *)MakronHyperblaster},
{"MakronRailgun", (byte *)MakronRailgun},
{"MakronSaveloc", (byte *)MakronSaveloc},
{"makronBFG", (byte *)makronBFG},
{"makron_run", (byte *)makron_run},
{"makron_walk", (byte *)makron_walk},
{"makron_prerailgun", (byte *)makron_prerailgun},
{"makron_brainsplorch", (byte *)makron_brainsplorch},
{"makron_step_right", (byte *)makron_step_right},
{"makron_step_left", (byte *)makron_step_left},
{"makron_popup", (byte *)makron_popup},
{"makron_hit", (byte *)makron_hit},
{"makron_stand", (byte *)makron_stand},
{"makron_taunt", (byte *)makron_taunt},
{"SP_monster_jorg", (byte *)SP_monster_jorg},
{"Jorg_CheckAttack", (byte *)Jorg_CheckAttack},
{"jorg_die", (byte *)jorg_die},
{"jorg_dead", (byte *)jorg_dead},
{"jorg_attack", (byte *)jorg_attack},
{"jorg_firebullet", (byte *)jorg_firebullet},
{"jorg_firebullet_left", (byte *)jorg_firebullet_left},
{"jorg_firebullet_right", (byte *)jorg_firebullet_right},
{"jorgBFG", (byte *)jorgBFG},
{"jorg_pain", (byte *)jorg_pain},
{"jorg_attack1", (byte *)jorg_attack1},
{"jorg_reattack1", (byte *)jorg_reattack1},
{"jorg_run", (byte *)jorg_run},
{"jorg_walk", (byte *)jorg_walk},
{"jorg_stand", (byte *)jorg_stand},
{"jorg_step_right", (byte *)jorg_step_right},
{"jorg_step_left", (byte *)jorg_step_left},
{"jorg_death_hit", (byte *)jorg_death_hit},
{"jorg_idle", (byte *)jorg_idle},
{"jorg_search", (byte *)jorg_search},
{"SP_monster_boss3_stand", (byte *)SP_monster_boss3_stand},
{"Think_Boss3Stand", (byte *)Think_Boss3Stand},
{"Use_Boss3", (byte *)Use_Boss3},
{"SP_monster_boss2", (byte *)SP_monster_boss2},
{"Boss2_CheckAttack", (byte *)Boss2_CheckAttack},
{"boss2_die", (byte *)boss2_die},
{"boss2_dead", (byte *)boss2_dead},
{"boss2_pain", (byte *)boss2_pain},
{"boss2_reattack_mg", (byte *)boss2_reattack_mg},
{"boss2_attack_mg", (byte *)boss2_attack_mg},
{"boss2_attack", (byte *)boss2_attack},
{"boss2_walk", (byte *)boss2_walk},
{"boss2_run", (byte *)boss2_run},
{"boss2_stand", (byte *)boss2_stand},
{"Boss2MachineGun", (byte *)Boss2MachineGun},
{"boss2_firebullet_left", (byte *)boss2_firebullet_left},
{"boss2_firebullet_right", (byte *)boss2_firebullet_right},
{"Boss2Rocket", (byte *)Boss2Rocket},
{"boss2_search", (byte *)boss2_search},
{"SP_monster_berserk", (byte *)SP_monster_berserk},
{"berserk_footstep", (byte *)berserk_footstep},
{"berserk_die", (byte *)berserk_die},
{"berserk_dead", (byte *)berserk_dead},
{"berserk_pain", (byte *)berserk_pain},
{"berserk_melee", (byte *)berserk_melee},
{"berserk_strike", (byte *)berserk_strike},
{"berserk_attack_club", (byte *)berserk_attack_club},
{"berserk_swing", (byte *)berserk_swing},
{"berserk_attack_spike", (byte *)berserk_attack_spike},
{"berserk_run", (byte *)berserk_run},
{"berserk_walk", (byte *)berserk_walk},
{"berserk_fidget", (byte *)berserk_fidget},
{"berserk_stand", (byte *)berserk_stand},
{"berserk_search", (byte *)berserk_search},
{"berserk_sight", (byte *)berserk_sight},
{"fire_trap", (byte *)fire_trap},
{"Trap_Think", (byte *)Trap_Think},
{"fire_plasma", (byte *)fire_plasma},
{"plasma_touch", (byte *)plasma_touch},
{"fire_heat", (byte *)fire_heat},
{"heat_think", (byte *)heat_think},
{"fire_ionripper", (byte *)fire_ionripper},
{"ionripper_touch", (byte *)ionripper_touch},
{"ionripper_sparks", (byte *)ionripper_sparks},
{"fire_bfg", (byte *)fire_bfg},
{"bfg_think", (byte *)bfg_think},
{"bfg_touch", (byte *)bfg_touch},
{"bfg_explode", (byte *)bfg_explode},
{"fire_rail", (byte *)fire_rail},
{"fire_rocket", (byte *)fire_rocket},
{"rocket_touch", (byte *)rocket_touch},
{"fire_grenade2", (byte *)fire_grenade2},
{"fire_grenade", (byte *)fire_grenade},
{"Grenade_Touch", (byte *)Grenade_Touch},
{"Grenade_Explode", (byte *)Grenade_Explode},
{"fire_blueblaster", (byte *)fire_blueblaster},
{"fire_blaster", (byte *)fire_blaster},
{"blaster_touch", (byte *)blaster_touch},
{"fire_shotgun", (byte *)fire_shotgun},
{"fire_bullet", (byte *)fire_bullet},
{"fire_lead", (byte *)fire_lead},
{"fire_hit", (byte *)fire_hit},
{"check_dodge", (byte *)check_dodge},
{"KillBox", (byte *)KillBox},
{"G_TouchSolids", (byte *)G_TouchSolids},
{"G_TouchTriggers", (byte *)G_TouchTriggers},
{"G_FreeEdict", (byte *)G_FreeEdict},
{"G_Spawn", (byte *)G_Spawn},
{"G_InitEdict", (byte *)G_InitEdict},
{"G_CopyString", (byte *)G_CopyString},
{"vectoangles", (byte *)vectoangles},
{"vectoyaw", (byte *)vectoyaw},
{"G_SetMovedir", (byte *)G_SetMovedir},
{"vtos", (byte *)vtos},
{"tv", (byte *)tv},
{"G_UseTargets", (byte *)G_UseTargets},
{"Think_Delay", (byte *)Think_Delay},
{"G_PickTarget", (byte *)G_PickTarget},
{"findradius", (byte *)findradius},
{"G_Find", (byte *)G_Find},
{"G_ProjectSource", (byte *)G_ProjectSource},
{"SP_turret_driver", (byte *)SP_turret_driver},
{"turret_driver_link", (byte *)turret_driver_link},
{"turret_driver_think", (byte *)turret_driver_think},
{"turret_driver_die", (byte *)turret_driver_die},
{"SP_turret_base", (byte *)SP_turret_base},
{"SP_turret_breach", (byte *)SP_turret_breach},
{"turret_breach_finish_init", (byte *)turret_breach_finish_init},
{"turret_breach_think", (byte *)turret_breach_think},
{"turret_breach_fire", (byte *)turret_breach_fire},
{"turret_blocked", (byte *)turret_blocked},
{"SnapToEights", (byte *)SnapToEights},
{"AnglesNormalize", (byte *)AnglesNormalize},
{"SP_trigger_monsterjump", (byte *)SP_trigger_monsterjump},
{"trigger_monsterjump_touch", (byte *)trigger_monsterjump_touch},
{"SP_trigger_gravity", (byte *)SP_trigger_gravity},
{"trigger_gravity_touch", (byte *)trigger_gravity_touch},
{"SP_trigger_hurt", (byte *)SP_trigger_hurt},
{"hurt_touch", (byte *)hurt_touch},
{"hurt_use", (byte *)hurt_use},
{"SP_trigger_push", (byte *)SP_trigger_push},
{"trigger_push_active", (byte *)trigger_push_active},
{"trigger_push_inactive", (byte *)trigger_push_inactive},
{"trigger_effect", (byte *)trigger_effect},
{"trigger_push_touch", (byte *)trigger_push_touch},
{"SP_trigger_always", (byte *)SP_trigger_always},
{"SP_trigger_counter", (byte *)SP_trigger_counter},
{"trigger_counter_use", (byte *)trigger_counter_use},
{"SP_trigger_key", (byte *)SP_trigger_key},
{"trigger_key_use", (byte *)trigger_key_use},
{"SP_trigger_relay", (byte *)SP_trigger_relay},
{"trigger_relay_use", (byte *)trigger_relay_use},
{"SP_trigger_once", (byte *)SP_trigger_once},
{"SP_trigger_multiple", (byte *)SP_trigger_multiple},
{"trigger_enable", (byte *)trigger_enable},
{"Touch_Multi", (byte *)Touch_Multi},
{"Use_Multi", (byte *)Use_Multi},
{"multi_trigger", (byte *)multi_trigger},
{"multi_wait", (byte *)multi_wait},
{"InitTrigger", (byte *)InitTrigger},
{"SP_target_earthquake", (byte *)SP_target_earthquake},
{"target_earthquake_use", (byte *)target_earthquake_use},
{"target_earthquake_think", (byte *)target_earthquake_think},
{"SP_target_lightramp", (byte *)SP_target_lightramp},
{"target_lightramp_use", (byte *)target_lightramp_use},
{"target_lightramp_think", (byte *)target_lightramp_think},
{"SP_target_mal_laser", (byte *)SP_target_mal_laser},
{"mal_laser_think", (byte *)mal_laser_think},
{"target_mal_laser_use", (byte *)target_mal_laser_use},
{"target_mal_laser_off", (byte *)target_mal_laser_off},
{"target_mal_laser_on", (byte *)target_mal_laser_on},
{"SP_target_laser", (byte *)SP_target_laser},
{"target_laser_start", (byte *)target_laser_start},
{"target_laser_use", (byte *)target_laser_use},
{"target_laser_off", (byte *)target_laser_off},
{"target_laser_on", (byte *)target_laser_on},
{"target_laser_think", (byte *)target_laser_think},
{"SP_target_crosslevel_target", (byte *)SP_target_crosslevel_target},
{"target_crosslevel_target_think", (byte *)target_crosslevel_target_think},
{"SP_target_crosslevel_trigger", (byte *)SP_target_crosslevel_trigger},
{"trigger_crosslevel_trigger_use", (byte *)trigger_crosslevel_trigger_use},
{"SP_target_blaster", (byte *)SP_target_blaster},
{"use_target_blaster", (byte *)use_target_blaster},
{"SP_target_spawner", (byte *)SP_target_spawner},
{"use_target_spawner", (byte *)use_target_spawner},
{"SP_target_splash", (byte *)SP_target_splash},
{"use_target_splash", (byte *)use_target_splash},
{"SP_target_changelevel", (byte *)SP_target_changelevel},
{"use_target_changelevel", (byte *)use_target_changelevel},
{"SP_target_explosion", (byte *)SP_target_explosion},
{"use_target_explosion", (byte *)use_target_explosion},
{"target_explosion_explode", (byte *)target_explosion_explode},
{"SP_target_goal", (byte *)SP_target_goal},
{"use_target_goal", (byte *)use_target_goal},
{"SP_target_secret", (byte *)SP_target_secret},
{"use_target_secret", (byte *)use_target_secret},
{"SP_target_help", (byte *)SP_target_help},
{"Use_Target_Help", (byte *)Use_Target_Help},
{"Target_Help_Think", (byte *)Target_Help_Think},
{"SP_target_speaker", (byte *)SP_target_speaker},
{"Use_Target_Speaker", (byte *)Use_Target_Speaker},
{"SP_target_temp_entity", (byte *)SP_target_temp_entity},
{"Use_Target_Tent", (byte *)Use_Target_Tent},
{"ServerCommand", (byte *)ServerCommand},
{"SVCmd_WriteIP_f", (byte *)SVCmd_WriteIP_f},
{"SVCmd_ListIP_f", (byte *)SVCmd_ListIP_f},
{"SVCmd_RemoveIP_f", (byte *)SVCmd_RemoveIP_f},
{"SVCmd_AddIP_f", (byte *)SVCmd_AddIP_f},
{"SV_FilterPacket", (byte *)SV_FilterPacket},
{"Svcmd_Test_f", (byte *)Svcmd_Test_f},
{"SP_worldspawn", (byte *)SP_worldspawn},
{"SpawnEntities", (byte *)SpawnEntities},
{"G_FindTeams", (byte *)G_FindTeams},
{"ED_ParseEdict", (byte *)ED_ParseEdict},
{"ED_ParseField", (byte *)ED_ParseField},
{"ED_NewString", (byte *)ED_NewString},
{"ED_CallSpawn", (byte *)ED_CallSpawn},
{"G_RunEntity", (byte *)G_RunEntity},
{"SV_Physics_Step", (byte *)SV_Physics_Step},
{"SV_AddRotationalFriction", (byte *)SV_AddRotationalFriction},
{"SV_Physics_Toss", (byte *)SV_Physics_Toss},
{"SV_Physics_Noclip", (byte *)SV_Physics_Noclip},
{"SV_Physics_None", (byte *)SV_Physics_None},
{"SV_Physics_Pusher", (byte *)SV_Physics_Pusher},
{"SV_Push", (byte *)SV_Push},
{"SV_PushEntity", (byte *)SV_PushEntity},
{"RealBoundingBox", (byte *)RealBoundingBox},
{"SV_AddGravity", (byte *)SV_AddGravity},
{"SV_FlyMove", (byte *)SV_FlyMove},
{"ClipVelocity", (byte *)ClipVelocity},
{"SV_Impact", (byte *)SV_Impact},
{"SV_RunThink", (byte *)SV_RunThink},
{"SV_CheckVelocity", (byte *)SV_CheckVelocity},
{"SV_TestEntityPosition", (byte *)SV_TestEntityPosition},
{"swimmonster_start", (byte *)swimmonster_start},
{"swimmonster_start_go", (byte *)swimmonster_start_go},
{"flymonster_start", (byte *)flymonster_start},
{"flymonster_start_go", (byte *)flymonster_start_go},
{"walkmonster_start", (byte *)walkmonster_start},
{"walkmonster_start_go", (byte *)walkmonster_start_go},
{"monster_start_go", (byte *)monster_start_go},
{"monster_start", (byte *)monster_start},
{"monster_death_use", (byte *)monster_death_use},
{"monster_triggered_start", (byte *)monster_triggered_start},
{"monster_triggered_spawn_use", (byte *)monster_triggered_spawn_use},
{"monster_triggered_spawn", (byte *)monster_triggered_spawn},
{"monster_use", (byte *)monster_use},
{"monster_think", (byte *)monster_think},
{"M_MoveFrame", (byte *)M_MoveFrame},
{"M_SetEffects", (byte *)M_SetEffects},
{"M_droptofloor", (byte *)M_droptofloor},
{"M_WorldEffects", (byte *)M_WorldEffects},
{"M_CatagorizePosition", (byte *)M_CatagorizePosition},
{"M_CheckGround", (byte *)M_CheckGround},
{"AttackFinished", (byte *)AttackFinished},
{"M_FlyCheck", (byte *)M_FlyCheck},
{"M_FliesOn", (byte *)M_FliesOn},
{"M_FliesOff", (byte *)M_FliesOff},
{"monster_fire_bfg", (byte *)monster_fire_bfg},
{"monster_fire_railgun", (byte *)monster_fire_railgun},
{"monster_fire_rocket", (byte *)monster_fire_rocket},
{"monster_fire_grenade", (byte *)monster_fire_grenade},
{"monster_dabeam", (byte *)monster_dabeam},
{"dabeam_hit", (byte *)dabeam_hit},
{"monster_fire_heat", (byte *)monster_fire_heat},
{"monster_fire_ionripper", (byte *)monster_fire_ionripper},
{"monster_fire_blueblaster", (byte *)monster_fire_blueblaster},
{"monster_fire_blaster", (byte *)monster_fire_blaster},
{"monster_fire_shotgun", (byte *)monster_fire_shotgun},
{"monster_fire_bullet", (byte *)monster_fire_bullet},
{"SP_misc_nuke", (byte *)SP_misc_nuke},
{"use_nuke", (byte *)use_nuke},
{"SP_misc_amb4", (byte *)SP_misc_amb4},
{"amb4_think", (byte *)amb4_think},
{"SP_misc_teleporter_dest", (byte *)SP_misc_teleporter_dest},
{"SP_misc_teleporter", (byte *)SP_misc_teleporter},
{"teleporter_touch", (byte *)teleporter_touch},
{"SP_func_clock", (byte *)SP_func_clock},
{"func_clock_use", (byte *)func_clock_use},
{"func_clock_think", (byte *)func_clock_think},
{"func_clock_format_countdown", (byte *)func_clock_format_countdown},
{"func_clock_reset", (byte *)func_clock_reset},
{"SP_target_string", (byte *)SP_target_string},
{"target_string_use", (byte *)target_string_use},
{"SP_target_character", (byte *)SP_target_character},
{"SP_misc_gib_head", (byte *)SP_misc_gib_head},
{"SP_misc_gib_leg", (byte *)SP_misc_gib_leg},
{"SP_misc_gib_arm", (byte *)SP_misc_gib_arm},
{"SP_light_mine2", (byte *)SP_light_mine2},
{"SP_light_mine1", (byte *)SP_light_mine1},
{"SP_misc_satellite_dish", (byte *)SP_misc_satellite_dish},
{"misc_satellite_dish_use", (byte *)misc_satellite_dish_use},
{"misc_satellite_dish_think", (byte *)misc_satellite_dish_think},
{"SP_misc_transport", (byte *)SP_misc_transport},
{"SP_misc_strogg_ship", (byte *)SP_misc_strogg_ship},
{"misc_strogg_ship_use", (byte *)misc_strogg_ship_use},
{"SP_misc_viper_missile", (byte *)SP_misc_viper_missile},
{"misc_viper_missile_use", (byte *)misc_viper_missile_use},
{"SP_misc_viper_bomb", (byte *)SP_misc_viper_bomb},
{"misc_viper_bomb_use", (byte *)misc_viper_bomb_use},
{"misc_viper_bomb_prethink", (byte *)misc_viper_bomb_prethink},
{"misc_viper_bomb_touch", (byte *)misc_viper_bomb_touch},
{"SP_misc_bigviper", (byte *)SP_misc_bigviper},
{"SP_misc_crashviper", (byte *)SP_misc_crashviper},
{"SP_misc_viper", (byte *)SP_misc_viper},
{"misc_viper_use", (byte *)misc_viper_use},
{"SP_misc_deadsoldier", (byte *)SP_misc_deadsoldier},
{"misc_deadsoldier_die", (byte *)misc_deadsoldier_die},
{"SP_misc_banner", (byte *)SP_misc_banner},
{"misc_banner_think", (byte *)misc_banner_think},
{"SP_monster_commander_body", (byte *)SP_monster_commander_body},
{"commander_body_drop", (byte *)commander_body_drop},
{"commander_body_use", (byte *)commander_body_use},
{"commander_body_think", (byte *)commander_body_think},
{"SP_misc_easterchick2", (byte *)SP_misc_easterchick2},
{"misc_easterchick2_think", (byte *)misc_easterchick2_think},
{"SP_misc_easterchick", (byte *)SP_misc_easterchick},
{"misc_easterchick_think", (byte *)misc_easterchick_think},
{"SP_misc_eastertank", (byte *)SP_misc_eastertank},
{"misc_eastertank_think", (byte *)misc_eastertank_think},
{"SP_misc_blackhole", (byte *)SP_misc_blackhole},
{"misc_blackhole_think", (byte *)misc_blackhole_think},
{"misc_blackhole_use", (byte *)misc_blackhole_use},
{"SP_misc_explobox", (byte *)SP_misc_explobox},
{"barrel_delay", (byte *)barrel_delay},
{"barrel_explode", (byte *)barrel_explode},
{"barrel_touch", (byte *)barrel_touch},
{"SP_func_explosive", (byte *)SP_func_explosive},
{"func_explosive_spawn", (byte *)func_explosive_spawn},
{"func_explosive_use", (byte *)func_explosive_use},
{"func_explosive_explode", (byte *)func_explosive_explode},
{"SP_func_object", (byte *)SP_func_object},
{"func_object_use", (byte *)func_object_use},
{"func_object_release", (byte *)func_object_release},
{"func_object_touch", (byte *)func_object_touch},
{"SP_func_wall", (byte *)SP_func_wall},
{"func_wall_use", (byte *)func_wall_use},
{"SP_light", (byte *)SP_light},
{"light_use", (byte *)light_use},
{"SP_info_notnull", (byte *)SP_info_notnull},
{"SP_info_null", (byte *)SP_info_null},
{"SP_viewthing", (byte *)SP_viewthing},
{"TH_viewthing", (byte *)TH_viewthing},
{"SP_point_combat", (byte *)SP_point_combat},
{"point_combat_touch", (byte *)point_combat_touch},
{"SP_path_corner", (byte *)SP_path_corner},
{"path_corner_touch", (byte *)path_corner_touch},
{"BecomeExplosion2", (byte *)BecomeExplosion2},
{"BecomeExplosion1", (byte *)BecomeExplosion1},
{"ThrowDebris", (byte *)ThrowDebris},
{"debris_die", (byte *)debris_die},
{"ThrowClientHead", (byte *)ThrowClientHead},
{"ThrowHeadACID", (byte *)ThrowHeadACID},
{"ThrowGibACID", (byte *)ThrowGibACID},
{"ThrowHead", (byte *)ThrowHead},
{"ThrowGib", (byte *)ThrowGib},
{"gib_die", (byte *)gib_die},
{"gib_touch", (byte *)gib_touch},
{"gib_think", (byte *)gib_think},
{"ClipGibVelocity", (byte *)ClipGibVelocity},
{"VelocityForDamage", (byte *)VelocityForDamage},
{"SP_func_areaportal", (byte *)SP_func_areaportal},
{"Use_Areaportal", (byte *)Use_Areaportal},
{"G_RunFrame", (byte *)G_RunFrame},
{"ExitLevel", (byte *)ExitLevel},
{"CheckDMRules", (byte *)CheckDMRules},
{"CheckNeedPass", (byte *)CheckNeedPass},
{"EndDMLevel", (byte *)EndDMLevel},
{"CreateTargetChangeLevel", (byte *)CreateTargetChangeLevel},
{"ClientEndServerFrames", (byte *)ClientEndServerFrames},
{"Com_Printf", (byte *)Com_Printf},
{"Sys_Error", (byte *)Sys_Error},
{"GetGameAPI", (byte *)GetGameAPI},
{"ShutdownGame", (byte *)ShutdownGame},
{"SetItemNames", (byte *)SetItemNames},
{"InitItems", (byte *)InitItems},
{"SP_item_foodcube", (byte *)SP_item_foodcube},
{"SP_item_health_mega", (byte *)SP_item_health_mega},
{"SP_item_health_large", (byte *)SP_item_health_large},
{"SP_item_health_small", (byte *)SP_item_health_small},
{"SP_item_health", (byte *)SP_item_health},
{"SpawnItem", (byte *)SpawnItem},
{"PrecacheItem", (byte *)PrecacheItem},
{"droptofloor", (byte *)droptofloor},
{"Use_Item", (byte *)Use_Item},
{"Drop_Item", (byte *)Drop_Item},
{"drop_make_touchable", (byte *)drop_make_touchable},
{"drop_temp_touch", (byte *)drop_temp_touch},
{"Touch_Item", (byte *)Touch_Item},
{"Drop_PowerArmor", (byte *)Drop_PowerArmor},
{"Pickup_PowerArmor", (byte *)Pickup_PowerArmor},
{"Use_PowerArmor", (byte *)Use_PowerArmor},
{"PowerArmorType", (byte *)PowerArmorType},
{"Pickup_Armor", (byte *)Pickup_Armor},
{"ArmorIndex", (byte *)ArmorIndex},
{"Pickup_Health", (byte *)Pickup_Health},
{"MegaHealth_think", (byte *)MegaHealth_think},
{"Drop_Ammo", (byte *)Drop_Ammo},
{"Pickup_Ammo", (byte *)Pickup_Ammo},
{"Add_Ammo", (byte *)Add_Ammo},
{"Pickup_Key", (byte *)Pickup_Key},
{"Use_Silencer", (byte *)Use_Silencer},
{"Use_Invulnerability", (byte *)Use_Invulnerability},
{"Use_Envirosuit", (byte *)Use_Envirosuit},
{"Use_Breather", (byte *)Use_Breather},
{"Use_QuadFire", (byte *)Use_QuadFire},
{"Use_Quad", (byte *)Use_Quad},
{"Pickup_Pack", (byte *)Pickup_Pack},
{"Pickup_Bandolier", (byte *)Pickup_Bandolier},
{"Pickup_AncientHead", (byte *)Pickup_AncientHead},
{"Pickup_Adrenaline", (byte *)Pickup_Adrenaline},
{"Drop_General", (byte *)Drop_General},
{"Pickup_Powerup", (byte *)Pickup_Powerup},
{"SetRespawn", (byte *)SetRespawn},
{"DoRespawn", (byte *)DoRespawn},
{"FindItem", (byte *)FindItem},
{"FindItemByClassname", (byte *)FindItemByClassname},
{"GetItemByIndex", (byte *)GetItemByIndex},
{"SP_object_repair", (byte *)SP_object_repair},
{"object_repair_sparks", (byte *)object_repair_sparks},
{"object_repair_dead", (byte *)object_repair_dead},
{"object_repair_fx", (byte *)object_repair_fx},
{"SP_rotating_light", (byte *)SP_rotating_light},
{"rotating_light_use", (byte *)rotating_light_use},
{"rotating_light_killed", (byte *)rotating_light_killed},
{"rotating_light_alarm", (byte *)rotating_light_alarm},
{"SP_func_killbox", (byte *)SP_func_killbox},
{"use_killbox", (byte *)use_killbox},
{"SP_func_door_secret", (byte *)SP_func_door_secret},
{"door_secret_die", (byte *)door_secret_die},
{"door_secret_blocked", (byte *)door_secret_blocked},
{"door_secret_done", (byte *)door_secret_done},
{"door_secret_move6", (byte *)door_secret_move6},
{"door_secret_move5", (byte *)door_secret_move5},
{"door_secret_move4", (byte *)door_secret_move4},
{"door_secret_move3", (byte *)door_secret_move3},
{"door_secret_move2", (byte *)door_secret_move2},
{"door_secret_move1", (byte *)door_secret_move1},
{"door_secret_use", (byte *)door_secret_use},
{"SP_func_conveyor", (byte *)SP_func_conveyor},
{"func_conveyor_use", (byte *)func_conveyor_use},
{"SP_func_timer", (byte *)SP_func_timer},
{"func_timer_use", (byte *)func_timer_use},
{"func_timer_think", (byte *)func_timer_think},
{"SP_trigger_elevator", (byte *)SP_trigger_elevator},
{"trigger_elevator_init", (byte *)trigger_elevator_init},
{"trigger_elevator_use", (byte *)trigger_elevator_use},
{"SP_func_train", (byte *)SP_func_train},
{"train_use", (byte *)train_use},
{"func_train_find", (byte *)func_train_find},
{"train_resume", (byte *)train_resume},
{"train_next", (byte *)train_next},
{"train_wait", (byte *)train_wait},
{"train_blocked", (byte *)train_blocked},
{"SP_func_water", (byte *)SP_func_water},
{"SP_func_door_rotating", (byte *)SP_func_door_rotating},
{"SP_func_door", (byte *)SP_func_door},
{"door_touch", (byte *)door_touch},
{"door_killed", (byte *)door_killed},
{"door_blocked", (byte *)door_blocked},
{"Think_SpawnDoorTrigger", (byte *)Think_SpawnDoorTrigger},
{"Think_CalcMoveSpeed", (byte *)Think_CalcMoveSpeed},
{"Touch_DoorTrigger", (byte *)Touch_DoorTrigger},
{"door_use", (byte *)door_use},
{"door_go_up", (byte *)door_go_up},
{"door_go_down", (byte *)door_go_down},
{"door_hit_bottom", (byte *)door_hit_bottom},
{"door_hit_top", (byte *)door_hit_top},
{"door_use_areaportals", (byte *)door_use_areaportals},
{"SP_func_button", (byte *)SP_func_button},
{"button_killed", (byte *)button_killed},
{"button_touch", (byte *)button_touch},
{"button_use", (byte *)button_use},
{"button_fire", (byte *)button_fire},
{"button_wait", (byte *)button_wait},
{"button_return", (byte *)button_return},
{"button_done", (byte *)button_done},
{"SP_func_rotating", (byte *)SP_func_rotating},
{"rotating_use", (byte *)rotating_use},
{"rotating_touch", (byte *)rotating_touch},
{"rotating_blocked", (byte *)rotating_blocked},
{"SP_func_plat", (byte *)SP_func_plat},
{"plat_spawn_inside_trigger", (byte *)plat_spawn_inside_trigger},
{"Touch_Plat_Center", (byte *)Touch_Plat_Center},
{"Use_Plat", (byte *)Use_Plat},
{"plat_blocked", (byte *)plat_blocked},
{"plat_go_up", (byte *)plat_go_up},
{"plat_go_down", (byte *)plat_go_down},
{"plat_hit_bottom", (byte *)plat_hit_bottom},
{"plat_hit_top", (byte *)plat_hit_top},
{"Think_AccelMove", (byte *)Think_AccelMove},
{"plat_Accelerate", (byte *)plat_Accelerate},
{"plat_CalcAcceleratedMove", (byte *)plat_CalcAcceleratedMove},
{"AngleMove_Calc", (byte *)AngleMove_Calc},
{"AngleMove_Begin", (byte *)AngleMove_Begin},
{"AngleMove_Final", (byte *)AngleMove_Final},
{"AngleMove_Done", (byte *)AngleMove_Done},
{"Move_Calc", (byte *)Move_Calc},
{"Move_Begin", (byte *)Move_Begin},
{"Move_Final", (byte *)Move_Final},
{"Move_Done", (byte *)Move_Done},
{"T_RadiusDamage", (byte *)T_RadiusDamage},
{"T_Damage", (byte *)T_Damage},
{"M_ReactToDamage", (byte *)M_ReactToDamage},
{"CheckArmor", (byte *)CheckArmor},
{"CheckPowerArmor", (byte *)CheckPowerArmor},
{"SpawnDamage", (byte *)SpawnDamage},
{"Killed", (byte *)Killed},
{"CanDamage", (byte *)CanDamage},
{"ClientCommand", (byte *)ClientCommand},
{"Cmd_PlayerList_f", (byte *)Cmd_PlayerList_f},
{"Cmd_Say_f", (byte *)Cmd_Say_f},
{"Cmd_Wave_f", (byte *)Cmd_Wave_f},
{"Cmd_Players_f", (byte *)Cmd_Players_f},
{"PlayerSort", (byte *)PlayerSort},
{"Cmd_PutAway_f", (byte *)Cmd_PutAway_f},
{"Cmd_Kill_f", (byte *)Cmd_Kill_f},
{"Cmd_InvDrop_f", (byte *)Cmd_InvDrop_f},
{"Cmd_WeapLast_f", (byte *)Cmd_WeapLast_f},
{"Cmd_WeapNext_f", (byte *)Cmd_WeapNext_f},
{"Cmd_WeapPrev_f", (byte *)Cmd_WeapPrev_f},
{"Cmd_InvUse_f", (byte *)Cmd_InvUse_f},
{"Cmd_Inven_f", (byte *)Cmd_Inven_f},
{"Cmd_Help_f", (byte *)Cmd_Help_f},
{"Cmd_Score_f", (byte *)Cmd_Score_f},
{"Cmd_Drop_f", (byte *)Cmd_Drop_f},
{"Cmd_Use_f", (byte *)Cmd_Use_f},
{"Cmd_Noclip_f", (byte *)Cmd_Noclip_f},
{"Cmd_Notarget_f", (byte *)Cmd_Notarget_f},
{"Cmd_God_f", (byte *)Cmd_God_f},
{"Cmd_Give_f", (byte *)Cmd_Give_f},
{"ValidateSelectedItem", (byte *)ValidateSelectedItem},
{"SelectPrevItem", (byte *)SelectPrevItem},
{"SelectNextItem", (byte *)SelectNextItem},
{"OnSameTeam", (byte *)OnSameTeam},
{"GetChaseTarget", (byte *)GetChaseTarget},
{"ChasePrev", (byte *)ChasePrev},
{"ChaseNext", (byte *)ChaseNext},
{"UpdateChaseCam", (byte *)UpdateChaseCam},
{"ai_run", (byte *)ai_run},
{"ai_checkattack", (byte *)ai_checkattack},
{"ai_run_slide", (byte *)ai_run_slide},
{"ai_run_missile", (byte *)ai_run_missile},
{"ai_run_melee", (byte *)ai_run_melee},
{"M_CheckAttack", (byte *)M_CheckAttack},
{"FacingIdeal", (byte *)FacingIdeal},
{"FindTarget", (byte *)FindTarget},
{"FoundTarget", (byte *)FoundTarget},
{"HuntTarget", (byte *)HuntTarget},
{"infront", (byte *)infront},
{"visible", (byte *)visible},
{"range", (byte *)range},
{"ai_turn", (byte *)ai_turn},
{"ai_charge", (byte *)ai_charge},
{"ai_walk", (byte *)ai_walk},
{"ai_stand", (byte *)ai_stand},
{"ai_move", (byte *)ai_move},
{"AI_SetSightClient", (byte *)AI_SetSightClient},
{"wait_and_change_think", (byte *)wait_and_change_think},
{0, 0}
