/* =======================================================================
 *
 * Insane animations
 *
 * =======================================================================
 */

#define FRAME_stand1 0
#define FRAME_stand2 1
#define FRAME_stand3 2
#define FRAME_stand4 3
#define FRAME_stand5 4
#define FRAME_stand6 5
#define FRAME_stand7 6
#define FRAME_stand8 7
#define FRAME_stand9 8
#define FRAME_stand10 9
#define FRAME_stand11 10
#define FRAME_stand12 11
#define FRAME_stand13 12
#define FRAME_stand14 13
#define FRAME_stand15 14
#define FRAME_stand16 15
#define FRAME_stand17 16
#define FRAME_stand18 17
#define FRAME_stand19 18
#define FRAME_stand20 19
#define FRAME_stand21 20
#define FRAME_stand22 21
#define FRAME_stand23 22
#define FRAME_stand24 23
#define FRAME_stand25 24
#define FRAME_stand26 25
#define FRAME_stand27 26
#define FRAME_stand28 27
#define FRAME_stand29 28
#define FRAME_stand30 29
#define FRAME_stand31 30
#define FRAME_stand32 31
#define FRAME_stand33 32
#define FRAME_stand34 33
#define FRAME_stand35 34
#define FRAME_stand36 35
#define FRAME_stand37 36
#define FRAME_stand38 37
#define FRAME_stand39 38
#define FRAME_stand40 39
#define FRAME_stand41 40
#define FRAME_stand42 41
#define FRAME_stand43 42
#define FRAME_stand44 43
#define FRAME_stand45 44
#define FRAME_stand46 45
#define FRAME_stand47 46
#define FRAME_stand48 47
#define FRAME_stand49 48
#define FRAME_stand50 49
#define FRAME_stand51 50
#define FRAME_stand52 51
#define FRAME_stand53 52
#define FRAME_stand54 53
#define FRAME_stand55 54
#define FRAME_stand56 55
#define FRAME_stand57 56
#define FRAME_stand58 57
#define FRAME_stand59 58
#define FRAME_stand60 59
#define FRAME_stand61 60
#define FRAME_stand62 61
#define FRAME_stand63 62
#define FRAME_stand64 63
#define FRAME_stand65 64
#define FRAME_stand66 65
#define FRAME_stand67 66
#define FRAME_stand68 67
#define FRAME_stand69 68
#define FRAME_stand70 69
#define FRAME_stand71 70
#define FRAME_stand72 71
#define FRAME_stand73 72
#define FRAME_stand74 73
#define FRAME_stand75 74
#define FRAME_stand76 75
#define FRAME_stand77 76
#define FRAME_stand78 77
#define FRAME_stand79 78
#define FRAME_stand80 79
#define FRAME_stand81 80
#define FRAME_stand82 81
#define FRAME_stand83 82
#define FRAME_stand84 83
#define FRAME_stand85 84
#define FRAME_stand86 85
#define FRAME_stand87 86
#define FRAME_stand88 87
#define FRAME_stand89 88
#define FRAME_stand90 89
#define FRAME_stand91 90
#define FRAME_stand92 91
#define FRAME_stand93 92
#define FRAME_stand94 93
#define FRAME_stand95 94
#define FRAME_stand96 95
#define FRAME_stand97 96
#define FRAME_stand98 97
#define FRAME_stand99 98
#define FRAME_stand100 99
#define FRAME_stand101 100
#define FRAME_stand102 101
#define FRAME_stand103 102
#define FRAME_stand104 103
#define FRAME_stand105 104
#define FRAME_stand106 105
#define FRAME_stand107 106
#define FRAME_stand108 107
#define FRAME_stand109 108
#define FRAME_stand110 109
#define FRAME_stand111 110
#define FRAME_stand112 111
#define FRAME_stand113 112
#define FRAME_stand114 113
#define FRAME_stand115 114
#define FRAME_stand116 115
#define FRAME_stand117 116
#define FRAME_stand118 117
#define FRAME_stand119 118
#define FRAME_stand120 119
#define FRAME_stand121 120
#define FRAME_stand122 121
#define FRAME_stand123 122
#define FRAME_stand124 123
#define FRAME_stand125 124
#define FRAME_stand126 125
#define FRAME_stand127 126
#define FRAME_stand128 127
#define FRAME_stand129 128
#define FRAME_stand130 129
#define FRAME_stand131 130
#define FRAME_stand132 131
#define FRAME_stand133 132
#define FRAME_stand134 133
#define FRAME_stand135 134
#define FRAME_stand136 135
#define FRAME_stand137 136
#define FRAME_stand138 137
#define FRAME_stand139 138
#define FRAME_stand140 139
#define FRAME_stand141 140
#define FRAME_stand142 141
#define FRAME_stand143 142
#define FRAME_stand144 143
#define FRAME_stand145 144
#define FRAME_stand146 145
#define FRAME_stand147 146
#define FRAME_stand148 147
#define FRAME_stand149 148
#define FRAME_stand150 149
#define FRAME_stand151 150
#define FRAME_stand152 151
#define FRAME_stand153 152
#define FRAME_stand154 153
#define FRAME_stand155 154
#define FRAME_stand156 155
#define FRAME_stand157 156
#define FRAME_stand158 157
#define FRAME_stand159 158
#define FRAME_stand160 159
#define FRAME_walk27 160
#define FRAME_walk28 161
#define FRAME_walk29 162
#define FRAME_walk30 163
#define FRAME_walk31 164
#define FRAME_walk32 165
#define FRAME_walk33 166
#define FRAME_walk34 167
#define FRAME_walk35 168
#define FRAME_walk36 169
#define FRAME_walk37 170
#define FRAME_walk38 171
#define FRAME_walk39 172
#define FRAME_walk1 173
#define FRAME_walk2 174
#define FRAME_walk3 175
#define FRAME_walk4 176
#define FRAME_walk5 177
#define FRAME_walk6 178
#define FRAME_walk7 179
#define FRAME_walk8 180
#define FRAME_walk9 181
#define FRAME_walk10 182
#define FRAME_walk11 183
#define FRAME_walk12 184
#define FRAME_walk13 185
#define FRAME_walk14 186
#define FRAME_walk15 187
#define FRAME_walk16 188
#define FRAME_walk17 189
#define FRAME_walk18 190
#define FRAME_walk19 191
#define FRAME_walk20 192
#define FRAME_walk21 193
#define FRAME_walk22 194
#define FRAME_walk23 195
#define FRAME_walk24 196
#define FRAME_walk25 197
#define FRAME_walk26 198
#define FRAME_st_pain2 199
#define FRAME_st_pain3 200
#define FRAME_st_pain4 201
#define FRAME_st_pain5 202
#define FRAME_st_pain6 203
#define FRAME_st_pain7 204
#define FRAME_st_pain8 205
#define FRAME_st_pain9 206
#define FRAME_st_pain10 207
#define FRAME_st_pain11 208
#define FRAME_st_pain12 209
#define FRAME_st_death2 210
#define FRAME_st_death3 211
#define FRAME_st_death4 212
#define FRAME_st_death5 213
#define FRAME_st_death6 214
#define FRAME_st_death7 215
#define FRAME_st_death8 216
#define FRAME_st_death9 217
#define FRAME_st_death10 218
#define FRAME_st_death11 219
#define FRAME_st_death12 220
#define FRAME_st_death13 221
#define FRAME_st_death14 222
#define FRAME_st_death15 223
#define FRAME_st_death16 224
#define FRAME_st_death17 225
#define FRAME_st_death18 226
#define FRAME_crawl1 227
#define FRAME_crawl2 228
#define FRAME_crawl3 229
#define FRAME_crawl4 230
#define FRAME_crawl5 231
#define FRAME_crawl6 232
#define FRAME_crawl7 233
#define FRAME_crawl8 234
#define FRAME_crawl9 235
#define FRAME_cr_pain2 236
#define FRAME_cr_pain3 237
#define FRAME_cr_pain4 238
#define FRAME_cr_pain5 239
#define FRAME_cr_pain6 240
#define FRAME_cr_pain7 241
#define FRAME_cr_pain8 242
#define FRAME_cr_pain9 243
#define FRAME_cr_pain10 244
#define FRAME_cr_death10 245
#define FRAME_cr_death11 246
#define FRAME_cr_death12 247
#define FRAME_cr_death13 248
#define FRAME_cr_death14 249
#define FRAME_cr_death15 250
#define FRAME_cr_death16 251
#define FRAME_cross1 252
#define FRAME_cross2 253
#define FRAME_cross3 254
#define FRAME_cross4 255
#define FRAME_cross5 256
#define FRAME_cross6 257
#define FRAME_cross7 258
#define FRAME_cross8 259
#define FRAME_cross9 260
#define FRAME_cross10 261
#define FRAME_cross11 262
#define FRAME_cross12 263
#define FRAME_cross13 264
#define FRAME_cross14 265
#define FRAME_cross15 266
#define FRAME_cross16 267
#define FRAME_cross17 268
#define FRAME_cross18 269
#define FRAME_cross19 270
#define FRAME_cross20 271
#define FRAME_cross21 272
#define FRAME_cross22 273
#define FRAME_cross23 274
#define FRAME_cross24 275
#define FRAME_cross25 276
#define FRAME_cross26 277
#define FRAME_cross27 278
#define FRAME_cross28 279
#define FRAME_cross29 280
#define FRAME_cross30 281

#define MODEL_SCALE 1.000000
