/* =======================================================================
 *
 * Mutant animations.
 *
 * =======================================================================
 */ 

#define FRAME_attack01 0
#define FRAME_attack02 1
#define FRAME_attack03 2
#define FRAME_attack04 3
#define FRAME_attack05 4
#define FRAME_attack06 5
#define FRAME_attack07 6
#define FRAME_attack08 7
#define FRAME_attack09 8
#define FRAME_attack10 9
#define FRAME_attack11 10
#define FRAME_attack12 11
#define FRAME_attack13 12
#define FRAME_attack14 13
#define FRAME_attack15 14
#define FRAME_death101 15
#define FRAME_death102 16
#define FRAME_death103 17
#define FRAME_death104 18
#define FRAME_death105 19
#define FRAME_death106 20
#define FRAME_death107 21
#define FRAME_death108 22
#define FRAME_death109 23
#define FRAME_death201 24
#define FRAME_death202 25
#define FRAME_death203 26
#define FRAME_death204 27
#define FRAME_death205 28
#define FRAME_death206 29
#define FRAME_death207 30
#define FRAME_death208 31
#define FRAME_death209 32
#define FRAME_death210 33
#define FRAME_pain101 34
#define FRAME_pain102 35
#define FRAME_pain103 36
#define FRAME_pain104 37
#define FRAME_pain105 38
#define FRAME_pain201 39
#define FRAME_pain202 40
#define FRAME_pain203 41
#define FRAME_pain204 42
#define FRAME_pain205 43
#define FRAME_pain206 44
#define FRAME_pain301 45
#define FRAME_pain302 46
#define FRAME_pain303 47
#define FRAME_pain304 48
#define FRAME_pain305 49
#define FRAME_pain306 50
#define FRAME_pain307 51
#define FRAME_pain308 52
#define FRAME_pain309 53
#define FRAME_pain310 54
#define FRAME_pain311 55
#define FRAME_run03 56
#define FRAME_run04 57
#define FRAME_run05 58
#define FRAME_run06 59
#define FRAME_run07 60
#define FRAME_run08 61
#define FRAME_stand101 62
#define FRAME_stand102 63
#define FRAME_stand103 64
#define FRAME_stand104 65
#define FRAME_stand105 66
#define FRAME_stand106 67
#define FRAME_stand107 68
#define FRAME_stand108 69
#define FRAME_stand109 70
#define FRAME_stand110 71
#define FRAME_stand111 72
#define FRAME_stand112 73
#define FRAME_stand113 74
#define FRAME_stand114 75
#define FRAME_stand115 76
#define FRAME_stand116 77
#define FRAME_stand117 78
#define FRAME_stand118 79
#define FRAME_stand119 80
#define FRAME_stand120 81
#define FRAME_stand121 82
#define FRAME_stand122 83
#define FRAME_stand123 84
#define FRAME_stand124 85
#define FRAME_stand125 86
#define FRAME_stand126 87
#define FRAME_stand127 88
#define FRAME_stand128 89
#define FRAME_stand129 90
#define FRAME_stand130 91
#define FRAME_stand131 92
#define FRAME_stand132 93
#define FRAME_stand133 94
#define FRAME_stand134 95
#define FRAME_stand135 96
#define FRAME_stand136 97
#define FRAME_stand137 98
#define FRAME_stand138 99
#define FRAME_stand139 100
#define FRAME_stand140 101
#define FRAME_stand141 102
#define FRAME_stand142 103
#define FRAME_stand143 104
#define FRAME_stand144 105
#define FRAME_stand145 106
#define FRAME_stand146 107
#define FRAME_stand147 108
#define FRAME_stand148 109
#define FRAME_stand149 110
#define FRAME_stand150 111
#define FRAME_stand151 112
#define FRAME_stand152 113
#define FRAME_stand153 114
#define FRAME_stand154 115
#define FRAME_stand155 116
#define FRAME_stand156 117
#define FRAME_stand157 118
#define FRAME_stand158 119
#define FRAME_stand159 120
#define FRAME_stand160 121
#define FRAME_stand161 122
#define FRAME_stand162 123
#define FRAME_stand163 124
#define FRAME_stand164 125
#define FRAME_walk01 126
#define FRAME_walk02 127
#define FRAME_walk03 128
#define FRAME_walk04 129
#define FRAME_walk05 130
#define FRAME_walk06 131
#define FRAME_walk07 132
#define FRAME_walk08 133
#define FRAME_walk09 134
#define FRAME_walk10 135
#define FRAME_walk11 136
#define FRAME_walk12 137
#define FRAME_walk13 138
#define FRAME_walk14 139
#define FRAME_walk15 140
#define FRAME_walk16 141
#define FRAME_walk17 142
#define FRAME_walk18 143
#define FRAME_walk19 144
#define FRAME_walk20 145
#define FRAME_walk21 146
#define FRAME_walk22 147
#define FRAME_walk23 148

#define MODEL_SCALE 1.000000
